@@ -3,7 +3,4 @@ NUMBER_OF_ENTRIES_PER_PAGE = 35 # Number of entries per page. Used in both non-A
 LOG_ENTRIES_DAY_HEADINGS_DATE_FORMAT = "l j F Y" # Headings (per day basis) date format in timeline.
 SINGLE_LOG_ENTRY_DATE_FORMAT = "g:i:s A" # Single log entry date format in timeline.
 
-ENABLE_CONTENT_TYPE_FILTER = True
-ENABLE_USER_FILTER = True
-
 DEBUG = False # Personal debug mode, which has nothing to do with global settings.DEBUG
\ No newline at end of file
