@@ -1,3 +1,9 @@
+__title__ = 'admin_timeline.forms'
+__version__ = '0.8'
+__build__ = 0x000008
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__all__ = ('FilterForm',)
+
 from django import forms
 from django.contrib.admin.models import LogEntry
 
@@ -11,6 +17,10 @@ content_types = lambda data: list(set([(d.content_type_id, d.content_type.name)
 class FilterForm(forms.Form):
     """
     Filter form to be used in the timeline.
+
+    ``users``: Users list to be filtered on.
+
+    ``content_types``: Content types to be filtered on.
     """
     def __init__(self, *args, **kwargs):
         super(FilterForm, self).__init__(*args, **kwargs)
